@@ -148,7 +148,7 @@ void AbstractKeyListModel::setRemarkKeys(const std::vector<GpgME::Key> &keys)
     d->m_remarkKeys = keys;
 }
 
-std::vector<GpgME::Key> AbstractKeyListModel::remarkKeys() const
+const std::vector<GpgME::Key> &AbstractKeyListModel::remarkKeys() const
 {
     return d->m_remarkKeys;
 }
@@ -515,11 +515,11 @@ QVariant AbstractKeyListModel::data(const Key &key, int row, int column, int rol
     } else if (role == Qt::DecorationRole) {
         return column == Icon ? returnIfValid(KeyFilterManager::instance()->icon(key)) : QVariant();
     } else if (role == Qt::BackgroundRole) {
-        if (!SystemInfo::isHighContrastModeActive()) {
+        if (!SystemInfo::isHighContrastColorSchemeInUse()) {
             return returnIfValid(KeyFilterManager::instance()->bgColor(key));
         }
     } else if (role == Qt::ForegroundRole) {
-        if (!SystemInfo::isHighContrastModeActive()) {
+        if (!SystemInfo::isHighContrastColorSchemeInUse()) {
             return returnIfValid(KeyFilterManager::instance()->fgColor(key));
         }
     } else if (role == FingerprintRole) {
@@ -573,7 +573,7 @@ QVariant AbstractKeyListModel::data(const KeyGroup &group, int column, int role)
                                 return Kleo::canBeUsedForEncryption(key);
                             })
             ? QIcon::fromTheme(QStringLiteral("group"))
-            : QIcon::fromTheme(QStringLiteral("emblem-warning"));
+            : QIcon::fromTheme(QStringLiteral("data-warning"));
     } else if (role == Qt::BackgroundRole) {
     } else if (role == Qt::ForegroundRole) {
     } else if (role == GroupRole) {
