@@ -7,14 +7,12 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_MODELS_KEYLISTSORTFILTERPROXYMODEL_H__
-#define __KLEOPATRA_MODELS_KEYLISTSORTFILTERPROXYMODEL_H__
-
-#include <QSortFilterProxyModel>
+#pragma once
 
 #include "keylistmodelinterface.h"
+#include "kleo_export.h"
 
-#include <kleo_export.h>
+#include <QSortFilterProxyModel>
 
 #include <memory>
 
@@ -28,12 +26,12 @@ namespace Kleo
 
 class KeyFilter;
 
-class KLEO_EXPORT AbstractKeyListSortFilterProxyModel : public QSortFilterProxyModel
-                                                      , public KeyListModelInterface
+class KLEO_EXPORT AbstractKeyListSortFilterProxyModel : public QSortFilterProxyModel, public KeyListModelInterface
 {
     Q_OBJECT
 protected:
     AbstractKeyListSortFilterProxyModel(const AbstractKeyListSortFilterProxyModel &);
+
 public:
     explicit AbstractKeyListSortFilterProxyModel(QObject *parent = nullptr);
     ~AbstractKeyListSortFilterProxyModel() override;
@@ -60,6 +58,7 @@ class KLEO_EXPORT KeyListSortFilterProxyModel : public AbstractKeyListSortFilter
     Q_OBJECT
 protected:
     KeyListSortFilterProxyModel(const KeyListSortFilterProxyModel &);
+
 public:
     explicit KeyListSortFilterProxyModel(QObject *parent = nullptr);
     ~KeyListSortFilterProxyModel() override;
@@ -78,5 +77,3 @@ private:
 };
 
 }
-
-#endif /* __KLEOPATRA_MODELS_KEYLISTMODEL_H__ */
