@@ -109,7 +109,7 @@ void Kleo::CryptoConfigModule::init()
             "properly. It did not return any components. "
             "Try running \"%1\" on the command line for more "
             "information.",
-            components.empty() ? QLatin1StringView("gpgconf --list-components") : QLatin1String("gpgconf --list-options gpg"));
+            components.empty() ? QLatin1StringView("gpgconf --list-components") : QLatin1StringView("gpgconf --list-options gpg"));
         auto layout = new QVBoxLayout;
         setLayout(layout);
         auto label = new QLabel(msg, this);
@@ -160,7 +160,7 @@ QStringList Kleo::CryptoConfigModule::sortComponentList(const QStringList &compo
 
 QStringList Kleo::CryptoConfigModule::sortGroupList(const QString &moduleName, const QStringList &groups)
 {
-    if (moduleName == QStringLiteral("gpg")) {
+    if (moduleName == QLatin1StringView("gpg")) {
         static const std::array<QString, 4> order = {
             QStringLiteral("Keyserver"),
             QStringLiteral("Configuration"),
@@ -168,7 +168,7 @@ QStringList Kleo::CryptoConfigModule::sortGroupList(const QString &moduleName, c
             QStringLiteral("Debug"),
         };
         return sortConfigEntries(order.begin(), order.end(), groups);
-    } else if (moduleName == QStringLiteral("gpgsm")) {
+    } else if (moduleName == QLatin1StringView("gpgsm")) {
         static const std::array<QString, 4> order = {
             QStringLiteral("Security"),
             QStringLiteral("Configuration"),
@@ -176,7 +176,7 @@ QStringList Kleo::CryptoConfigModule::sortGroupList(const QString &moduleName, c
             QStringLiteral("Debug"),
         };
         return sortConfigEntries(order.begin(), order.end(), groups);
-    } else if (moduleName == QStringLiteral("gpg-agent")) {
+    } else if (moduleName == QLatin1StringView("gpg-agent")) {
         static const std::array<QString, 5> order = {
             QStringLiteral("Security"),
             QStringLiteral("Passphrase policy"),
@@ -185,7 +185,7 @@ QStringList Kleo::CryptoConfigModule::sortGroupList(const QString &moduleName, c
             QStringLiteral("Debug"),
         };
         return sortConfigEntries(order.begin(), order.end(), groups);
-    } else if (moduleName == QStringLiteral("dirmngr")) {
+    } else if (moduleName == QLatin1StringView("dirmngr")) {
         static const std::array<QString, 10> order = {
             QStringLiteral("Keyserver"),
             QStringLiteral("HTTP"),
@@ -199,7 +199,7 @@ QStringList Kleo::CryptoConfigModule::sortGroupList(const QString &moduleName, c
             QStringLiteral("Debug"),
         };
         return sortConfigEntries(order.begin(), order.end(), groups);
-    } else if (moduleName == QStringLiteral("scdaemon")) {
+    } else if (moduleName == QLatin1StringView("scdaemon")) {
         static const std::array<QString, 4> order = {
             QStringLiteral("Monitor"),
             QStringLiteral("Configuration"),
@@ -879,14 +879,6 @@ void prepareURLCfgDialog(QDialog *dialog, DirectoryServicesWidget *dirserv, bool
 
 void Kleo::CryptoConfigEntryLDAPURL::slotOpenDialog()
 {
-    if (!gpgme_check_version("1.16.0")) {
-        KMessageBox::error(mPushButton->parentWidget(),
-                           i18n("Configuration of directory services is not possible "
-                                "because the used gpgme libraries are too old."),
-                           i18n("Sorry"));
-        return;
-    }
-
     // I'm a bad boy and I do it all on the stack. Enough classes already :)
     // This is just a simple dialog around the directory-services-widget
     QDialog dialog(mPushButton->parentWidget());
