@@ -18,7 +18,6 @@
 #include <QGpgME/Protocol>
 
 #include <QDialog>
-#include <QPixmap>
 
 #include <gpgme++/key.h>
 
@@ -27,7 +26,6 @@
 class QCheckBox;
 class QLabel;
 class QPoint;
-class QRegExp;
 class QTimer;
 class QVBoxLayout;
 
@@ -198,6 +196,6 @@ private:
     int mSavedOffsetY = 0;
 };
 
-}
+Q_DECLARE_OPERATORS_FOR_FLAGS(KeySelectionDialog::Options)
 
-Q_DECLARE_OPERATORS_FOR_FLAGS(Kleo::KeySelectionDialog::Options)
+}
