@@ -25,6 +25,7 @@
 
 #include <libkleo_debug.h>
 
+#include <KAboutComponent>
 #include <KLocalizedString>
 
 #include <QGpgME/CryptoConfig>
@@ -451,7 +452,18 @@ QString Kleo::stringFromGpgOutput(const QByteArray &ba)
 
 QStringList Kleo::backendVersionInfo()
 {
+    const auto components = backendComponents();
+
     QStringList versions;
+    for (const auto &component : components) {
+        versions.push_back(component.name() + u' ' + component.version());
+    }
+    return versions;
+}
+
+QList<KAboutComponent> Kleo::backendComponents()
+{
+    QList<KAboutComponent> components;
     if (Kleo::engineIsVersion(2, 2, 24, GpgME::GpgConfEngine)) {
         QProcess p;
         qCDebug(LIBKLEO_LOG) << "Running gpgconf --show-versions ...";
@@ -468,39 +480,40 @@ QStringList Kleo::backendVersionInfo()
             qCDebug(LIBKLEO_LOG) << "gpgconf stdout:" << output;
             const auto lines = output.split('\n');
             for (const auto &line : lines) {
-                if (line.startsWith("* GnuPG") || line.startsWith("* Libgcrypt")) {
-                    const auto components = line.split(' ');
-                    versions.push_back(QString::fromLatin1(components.at(1) + ' ' + components.value(2)));
+                if (line.startsWith("* GnuPG")) {
+                    const auto componentsLine = line.split(' ');
+                    components.append(KAboutComponent(QStringLiteral("GnuPG"),
+                                                      i18nc("@info", "GnuPG provides support for OpenPGP/LibrePGP and S/MIME."),
+                                                      QString::fromLatin1(componentsLine.value(2)),
+                                                      QStringLiteral("https://gnupg.org"),
+                                                      KAboutLicense::GPL_V3));
+                }
+
+                if (line.startsWith("* Libgcrypt")) {
+                    const auto componentsLine = line.split(' ');
+                    components.append(KAboutComponent(QStringLiteral("Libgcrypt"),
+                                                      i18nc("@info", "Libgcrypt is a general purpose cryptographic library."),
+                                                      QString::fromLatin1(componentsLine.value(2)),
+                                                      QStringLiteral("https://www.gnupg.org/software/libgcrypt/index.html"),
+                                                      KAboutLicense::LGPL_V2_1));
                 }
             }
         }
     }
-    return versions;
+    return components;
 }
 
 namespace
 {
 
-void runGpgConf(const QStringList &arguments)
+void startGpgConfDetached(const QStringList &arguments)
 {
-    QProcess process;
-    process.setProgram(Kleo::gpgConfPath());
-    process.setArguments(arguments);
-
-    qCDebug(LIBKLEO_LOG) << "Starting gpgconf (" << &process << ") with arguments" << process.arguments().join(QLatin1Char(' ')) << " ...";
-    process.start();
-
-    if (!process.waitForStarted(5000 /* wait at most 5 seconds */)) {
-        qCDebug(LIBKLEO_LOG) << "gpgconf failed to start:" << process.errorString() << "\nstderr:" << process.readAllStandardError();
-        return;
-    }
-    if (!process.waitForFinished(5000 /* wait at most 5 seconds */)) {
-        qCDebug(LIBKLEO_LOG) << "gpgconf did not exit after 5 seconds:" << process.errorString() << "\nstderr:" << process.readAllStandardError();
-        return;
-    }
-    qCDebug(LIBKLEO_LOG) << "gpgconf (" << &process << ") exited with exit code" << process.exitCode() << ")";
-    if (process.exitCode() > 0) {
-        qCDebug(LIBKLEO_LOG) << "gpgconf stderr:" << process.readAllStandardError();
+    const QString gpgconf = Kleo::gpgConfPath();
+    qCDebug(LIBKLEO_LOG) << "Starting" << gpgconf << arguments.join(QLatin1Char(' ')) << " ...";
+    if (QProcess::startDetached(gpgconf, arguments)) {
+        qCDebug(LIBKLEO_LOG) << "gpgconf was started successfully";
+    } else {
+        qCDebug(LIBKLEO_LOG) << "gpgconf failed to start";
     }
 }
 
@@ -511,23 +524,23 @@ auto startGpgConf(const QStringList &arguments, Function1 onSuccess, Function2 o
     process->setProgram(Kleo::gpgConfPath());
     process->setArguments(arguments);
 
-    QObject::connect(process, &QProcess::started, [process]() {
+    QObject::connect(process, &QProcess::started, process, [process]() {
         qCDebug(LIBKLEO_LOG).nospace() << "gpgconf (" << process << ") was started successfully";
     });
-    QObject::connect(process, &QProcess::errorOccurred, [process, onFailure](auto error) {
+    QObject::connect(process, &QProcess::errorOccurred, process, [process, onFailure](auto error) {
         qCDebug(LIBKLEO_LOG).nospace() << "Error while running gpgconf (" << process << "): " << error;
         process->deleteLater();
         onFailure();
     });
-    QObject::connect(process, &QProcess::readyReadStandardError, [process]() {
+    QObject::connect(process, &QProcess::readyReadStandardError, process, [process]() {
         for (const auto &line : process->readAllStandardError().trimmed().split('\n')) {
             qCDebug(LIBKLEO_LOG).nospace() << "gpgconf (" << process << ") stderr: " << line;
         }
     });
-    QObject::connect(process, &QProcess::readyReadStandardOutput, [process]() {
+    QObject::connect(process, &QProcess::readyReadStandardOutput, process, [process]() {
         (void)process->readAllStandardOutput(); /* ignore stdout */
     });
-    QObject::connect(process, &QProcess::finished, [process, onSuccess, onFailure](int exitCode, QProcess::ExitStatus exitStatus) {
+    QObject::connect(process, &QProcess::finished, process, [process, onSuccess, onFailure](int exitCode, QProcess::ExitStatus exitStatus) {
         if (exitStatus == QProcess::NormalExit) {
             qCDebug(LIBKLEO_LOG).nospace() << "gpgconf (" << process << ") exited (exit code: " << exitCode << ")";
             if (exitCode == 0) {
@@ -592,7 +605,7 @@ void Kleo::launchGpgAgent(Kleo::LaunchGpgAgentOptions options)
     if (QThread::currentThread()->loopLevel() > 0) {
         launchGpgAgentWithEventLoop();
     } else {
-        runGpgConf({QStringLiteral("--launch"), QStringLiteral("gpg-agent")});
+        startGpgConfDetached({QStringLiteral("--launch"), QStringLiteral("gpg-agent")});
     }
 }
 
@@ -613,19 +626,32 @@ void Kleo::restartGpgAgent()
 
 const std::vector<std::string> &Kleo::availableAlgorithms()
 {
-    static const std::vector<std::string> algos = {
-        "brainpoolP256r1",
-        "brainpoolP384r1",
-        "brainpoolP512r1",
-        "curve25519",
-        "curve448",
-        "nistp256",
-        "nistp384",
-        "nistp521",
-        "rsa2048",
-        "rsa3072",
-        "rsa4096",
-        // "secp256k1", // Curve secp256k1 is explicitly ignored
+    static std::vector<std::string> algos;
+    if (algos.empty()) {
+        algos.reserve(13);
+        algos = {
+            "brainpoolP256r1",
+            "brainpoolP384r1",
+            "brainpoolP512r1",
+            "curve25519",
+            "curve448",
+            "nistp256",
+            "nistp384",
+            "nistp521",
+            "rsa2048",
+            "rsa3072",
+            "rsa4096",
+            // "secp256k1", // Curve secp256k1 is explicitly ignored
+        };
+#if GPGMEPP_SUPPORTS_KYBER
+        if (engineIsVersion(2, 5, 2)) {
+            algos.insert(algos.end(),
+                         {
+                             "ky768_bp256",
+                             "ky1024_bp384",
+                         });
+        }
+#endif
     };
     return algos;
 }
