@@ -12,6 +12,8 @@
 
 #include "systeminfo.h"
 
+#include <KColorSchemeManager>
+
 #include <QByteArray>
 
 // #include "libkleo_debug.h"
@@ -38,9 +40,14 @@ bool Kleo::SystemInfo::isHighContrastModeActive()
 {
     static bool forceHighContrastMode = qgetenv("KLEO_HIGH_CONTRAST_MODE").toInt();
 #ifdef Q_OS_WIN
-    static bool highContrastModeActive = forceHighContrastMode || win_isHighContrastModeActive();
-    return highContrastModeActive;
+    return forceHighContrastMode || win_isHighContrastModeActive();
 #else
     return forceHighContrastMode;
 #endif
 }
+
+bool Kleo::SystemInfo::isHighContrastColorSchemeInUse()
+{
+    return KColorSchemeManager::instance()->activeSchemeId().isEmpty() // the default scheme is in use
+        && isHighContrastModeActive();
+}
